%global nspr_version 4.8.7
%global nss_util_version 3.12.9
%global nss_softokn_version 3.12.9

%define _libdir64 %{_prefix}/lib64

%global unsupported_tools_directory    %{_libdir}/nss/unsupported-tools
%global unsupported_tools_directory_64 %{_libdir64}/nss/unsupported-tools

Summary:          Network Security Services
Name:             nss
Version:          3.12.9
Release:          1
License:          MPLv1.1 or GPLv2+ or LGPLv2+
URL:              http://www.mozilla.org/projects/security/pki/nss/
Group:            System Environment/Libraries
BuildRoot:        %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires:    nspr-devel >= %{nspr_version}
BuildRequires:    nss-softokn-devel >= %{nss_softokn_version}
BuildRequires:    nss-util-devel >= %{nss_util_version}
BuildRequires:    sqlite-devel >= 3.6.23.1-1
BuildRequires:    zlib-devel
BuildRequires:    pkg-config
BuildRequires:    perl >= 5.8.8
BuildRequires:    patch

Requires:         nspr >= %{nspr_version}
Requires:         nss-util >= %{nss_util_version}
Requires:         nss-softokn >= %{nss_softokn_version}
Requires:         nss-system-init

Source0:          %{name}-%{version}-stripped.tar.bz2
Source1:          nss.pc.in
Source2:          nss-config.in

Source3:          blank-cert8.db
Source4:          blank-key3.db
Source5:          blank-secmod.db
Source6:          blank-cert9.db
Source7:          blank-key4.db
Source8:          system-pkcs11.txt
Source9:          setup-nsssysinit.sh

Source10:         PayPalEE.cert
Source12:         %{name}-pem-20101125.tar.bz2

Patch0:           %{name}-%{version}-aix.patch
Patch1:           %{name}-%{version}-aix-shlibpath.patch

Patch3:           renegotiate-transitional.patch
Patch6:           nss-enable-pem.patch
Patch7:           nsspem-642433.patch
Patch11:          nss-sysinit-fix-trustorder.patch
Patch12:          nss-sysinit-userdb-first.patch

%description
Network Security Services (NSS) is a set of libraries designed to
support cross-platform development of security-enabled client and
server applications. Applications built with NSS can support SSL v2
and v3, TLS, PKCS #5, PKCS #7, PKCS #11, PKCS #12, S/MIME, X.509
v3 certificates, and other security standards.


%package tools
Summary:          Tools for the Network Security Services
Group:            System Environment/Base
Requires:         %{name} = %{version}-%{release}
Requires:         zlib

%description tools
Network Security Services (NSS) is a set of libraries designed to
support cross-platform development of security-enabled client and
server applications. Applications built with NSS can support SSL v2
and v3, TLS, PKCS #5, PKCS #7, PKCS #11, PKCS #12, S/MIME, X.509
v3 certificates, and other security standards.

Install the nss-tools package if you need command-line tools to
manipulate the NSS certificate and key database.


%package sysinit
Summary:          System NSS Initilization
Group:            System Environment/Base
# providing nss-system-init without version so that it can
# be replaced by a better one, e.g. supplied by the os vendor
Provides:         nss-system-init
Requires:         %{name} = %{version}-%{release}
Requires:         coreutils, sed

%description sysinit
Default Operating System module that manages applications loading
NSS globally on the system. This module loads the system defined
PKCS #11 modules for NSS and chains with other NSS modules to load
any system or user configured modules.


%package devel
Summary:          Development libraries for Network Security Services
Group:            Development/Libraries
Requires:         %{name} = %{version}-%{release}
Requires:         nss-util-devel >= %{nss_util_version}
Requires:         nss-softokn-devel >= %{nss_softokn_version}
Requires:         nspr-devel >= %{nspr_version}
Requires:         pkg-config

%description devel
Header and Library files for doing development with Network Security Services.


%package pkcs11-devel
Summary:          Development libraries for PKCS #11 (Cryptoki) using NSS
Group:            Development/Libraries
Requires:         %{name}-devel = %{version}-%{release}

%description pkcs11-devel
Library files for developing PKCS #11 modules using basic NSS 
low level services.


%prep
%setup -q
%patch0
%{__cp} %{SOURCE10} ./mozilla/security/nss/tests/libpkix/certs
%setup -q -T -D -n %{name}-%{version} -a 12

export PATH=/opt/freeware/bin:$PATH
%patch3 -p0 -b .transitional
%patch6 -p0 -b .libpem
%patch7 -p0 -b .642433
%patch11 -p1 -b .643134
%patch12 -p0 -b .603313

mkdir mozilla-64
mv mozilla mozilla-32
cd mozilla-32
cp -r * ../mozilla-64

cd ..
%patch1


%build
export FREEBL_NO_DEPEND=1

# Enable compiler optimizations and disable debugging code
export BUILD_OPT=1

# Generate symbolic info for debuggers
XCFLAGS=
export XCFLAGS

export PKG_CONFIG_ALLOW_SYSTEM_LIBS=1
export PKG_CONFIG_ALLOW_SYSTEM_CFLAGS=1

export NSS_USE_SYSTEM_SQLITE=1

#####################################################################

# first build the 64-bit version
export OBJECT_MODE=64
export LDFLAGS="-L/opt/freeware/lib64 -L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"

export USE_64=1

NSPR_INCLUDE_DIR=`/usr/bin/pkg-config_64 --cflags-only-I nspr | sed 's/-I//'`
NSPR_LIB_DIR=`/usr/bin/pkg-config_64 --libs-only-L nspr | sed 's/-L//'`

export NSPR_INCLUDE_DIR
export NSPR_LIB_DIR

NSS_INCLUDE_DIR=`/usr/bin/pkg-config_64 --cflags-only-I nss-util | sed 's/-I//'`
NSS_LIB_DIR=`/usr/bin/pkg-config_64 --libs-only-L nss-util | sed 's/-L//'`

export NSS_INCLUDE_DIR
export NSS_LIB_DIR

# We only ship the nss proper libraries, no softoken nor util, yet
# we must compile with the entire source tree because nss needs
# private exports from util. The install section will ensure not
# to override nss-util and nss-softoken headers already installed.
#
gmake -C ./mozilla-64/security/coreconf
gmake -C ./mozilla-64/security/dbm
gmake -C ./mozilla-64/security/nss

# this needs to be extra specified, weird ...
gmake -C ./mozilla-64/security/nss/lib/sysinit

# Set up our package file
# The nspr_version and nss_{util|softokn}_version globals used
# here match the ones nss has for its Requires. 
%{__mkdir_p} ./mozilla-64/dist/pkgconfig
%{__cat} %{SOURCE1} | sed -e "s,%%libdir%%,%{_libdir64},g" \
                          -e "s,%%prefix%%,%{_prefix},g" \
                          -e "s,%%exec_prefix%%,%{_prefix},g" \
                          -e "s,%%includedir%%,%{_includedir}/nss3,g" \
                          -e "s,%%NSS_VERSION%%,%{version},g" \
                          -e "s,%%NSPR_VERSION%%,%{nspr_version},g" \
                          -e "s,%%NSSUTIL_VERSION%%,%{nss_util_version},g" \
                          -e "s,%%SOFTOKEN_VERSION%%,%{nss_softokn_version},g" \
                         > ./mozilla-64/dist/pkgconfig/nss.pc

NSS_VMAJOR=`cat mozilla-64/security/nss/lib/nss/nss.h | grep "#define.*NSS_VMAJOR" | awk '{print $3}'`
NSS_VMINOR=`cat mozilla-64/security/nss/lib/nss/nss.h | grep "#define.*NSS_VMINOR" | awk '{print $3}'`
NSS_VPATCH=`cat mozilla-64/security/nss/lib/nss/nss.h | grep "#define.*NSS_VPATCH" | awk '{print $3}'`

export NSS_VMAJOR 
export NSS_VMINOR 
export NSS_VPATCH

%{__cat} %{SOURCE2} | sed -e "s,@libdir@,%{_libdir64},g" \
                          -e "s,@prefix@,%{_prefix},g" \
                          -e "s,@exec_prefix@,%{_prefix},g" \
                          -e "s,@includedir@,%{_includedir}/nss3,g" \
                          -e "s,@MOD_MAJOR_VERSION@,$NSS_VMAJOR,g" \
                          -e "s,@MOD_MINOR_VERSION@,$NSS_VMINOR,g" \
                          -e "s,@MOD_PATCH_VERSION@,$NSS_VPATCH,g" \
                          > ./mozilla-64/dist/pkgconfig/nss-config

chmod 755 ./mozilla-64/dist/pkgconfig/nss-config

%{__cat} %{SOURCE9} > ./mozilla-64/dist/pkgconfig/setup-nsssysinit.sh
chmod 755 ./mozilla-64/dist/pkgconfig/setup-nsssysinit.sh

#####################################################################

# now build the 32-bit version
export OBJECT_MODE=32
export LDFLAGS="-L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"

export USE_64=

NSPR_INCLUDE_DIR=`/usr/bin/pkg-config --cflags-only-I nspr | sed 's/-I//'`
NSPR_LIB_DIR=`/usr/bin/pkg-config --libs-only-L nspr | sed 's/-L//'`

export NSPR_INCLUDE_DIR
export NSPR_LIB_DIR

NSS_INCLUDE_DIR=`/usr/bin/pkg-config --cflags-only-I nss-util | sed 's/-I//'`
NSS_LIB_DIR=`/usr/bin/pkg-config --libs-only-L nss-util | sed 's/-L//'`

export NSS_INCLUDE_DIR
export NSS_LIB_DIR

# We only ship the nss proper libraries, no softoken nor util, yet
# we must compile with the entire source tree because nss needs
# private exports from util. The install section will ensure not
# to override nss-util and nss-softoken headers already installed.
#
gmake -C ./mozilla-32/security/coreconf
gmake -C ./mozilla-32/security/dbm
gmake -C ./mozilla-32/security/nss

# this needs to be extra specified, weird ...
gmake -C ./mozilla-32/security/nss/lib/sysinit

# Set up our package file
# The nspr_version and nss_{util|softokn}_version globals used
# here match the ones nss has for its Requires. 
%{__mkdir_p} ./mozilla-32/dist/pkgconfig
%{__cat} %{SOURCE1} | sed -e "s,%%libdir%%,%{_libdir},g" \
                          -e "s,%%prefix%%,%{_prefix},g" \
                          -e "s,%%exec_prefix%%,%{_prefix},g" \
                          -e "s,%%includedir%%,%{_includedir}/nss3,g" \
                          -e "s,%%NSS_VERSION%%,%{version},g" \
                          -e "s,%%NSPR_VERSION%%,%{nspr_version},g" \
                          -e "s,%%NSSUTIL_VERSION%%,%{nss_util_version},g" \
                          -e "s,%%SOFTOKEN_VERSION%%,%{nss_softokn_version},g" \
                         > ./mozilla-32/dist/pkgconfig/nss.pc

NSS_VMAJOR=`cat mozilla-32/security/nss/lib/nss/nss.h | grep "#define.*NSS_VMAJOR" | awk '{print $3}'`
NSS_VMINOR=`cat mozilla-32/security/nss/lib/nss/nss.h | grep "#define.*NSS_VMINOR" | awk '{print $3}'`
NSS_VPATCH=`cat mozilla-32/security/nss/lib/nss/nss.h | grep "#define.*NSS_VPATCH" | awk '{print $3}'`

export NSS_VMAJOR 
export NSS_VMINOR 
export NSS_VPATCH

%{__cat} %{SOURCE2} | sed -e "s,@libdir@,%{_libdir},g" \
                          -e "s,@prefix@,%{_prefix},g" \
                          -e "s,@exec_prefix@,%{_prefix},g" \
                          -e "s,@includedir@,%{_includedir}/nss3,g" \
                          -e "s,@MOD_MAJOR_VERSION@,$NSS_VMAJOR,g" \
                          -e "s,@MOD_MINOR_VERSION@,$NSS_VMINOR,g" \
                          -e "s,@MOD_PATCH_VERSION@,$NSS_VPATCH,g" \
                          > ./mozilla-32/dist/pkgconfig/nss-config

chmod 755 ./mozilla-32/dist/pkgconfig/nss-config

%{__cat} %{SOURCE9} > ./mozilla-32/dist/pkgconfig/setup-nsssysinit.sh
chmod 755 ./mozilla-32/dist/pkgconfig/setup-nsssysinit.sh


%install
export PATH=/opt/freeware/bin:$PATH

[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

# There is no make install target so we'll do it ourselves.

%{__mkdir_p} ${RPM_BUILD_ROOT}%{_bindir}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_includedir}/nss3
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_libdir}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_libdir64}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_libdir}/pkgconfig
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_libdir64}/pkgconfig

# copy RTL-style shared libraries
for f in libnss3.so libnssckbi.so libnsspem.so libnsssysinit.so libsmime3.so libssl3.so ; do
    install -p -m 755 mozilla-32/dist/*.OBJ/lib/${f} ${RPM_BUILD_ROOT}%{_libdir}
    install -p -m 755 mozilla-64/dist/*.OBJ/lib/${f} ${RPM_BUILD_ROOT}%{_libdir64}
done

# build AIX-style shared libraries
export AR="ar -X32_64"
for f in libnss3 libnssckbi libnsspem libnsssysinit libsmime3 libssl3 ; do
    ${AR} -rv ${RPM_BUILD_ROOT}%{_libdir}/${f}.a mozilla-32/dist/*.OBJ/lib/${f}.so
    ${AR} -q  ${RPM_BUILD_ROOT}%{_libdir}/${f}.a mozilla-64/dist/*.OBJ/lib/${f}.so
done

# install the empty NSS db files
# legacy db
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_sysconfdir}/pki/nssdb
install -p -m 644 %{SOURCE3} ${RPM_BUILD_ROOT}%{_sysconfdir}/pki/nssdb/cert8.db
install -p -m 644 %{SOURCE4} ${RPM_BUILD_ROOT}%{_sysconfdir}/pki/nssdb/key3.db
install -p -m 644 %{SOURCE5} ${RPM_BUILD_ROOT}%{_sysconfdir}/pki/nssdb/secmod.db
# shared db
install -p -m 644 %{SOURCE6} ${RPM_BUILD_ROOT}%{_sysconfdir}/pki/nssdb/cert9.db
install -p -m 644 %{SOURCE7} ${RPM_BUILD_ROOT}%{_sysconfdir}/pki/nssdb/key4.db
install -p -m 644 %{SOURCE8} ${RPM_BUILD_ROOT}%{_sysconfdir}/pki/nssdb/pkcs11.txt
     
# copy the development libraries we want
for f in libcrmf.a libnssb.a libnssckfw.a ; do
    install -p -m 644 mozilla-32/dist/*.OBJ/lib/${f} ${RPM_BUILD_ROOT}%{_libdir}
    install -p -m 644 mozilla-64/dist/*.OBJ/lib/${f} ${RPM_BUILD_ROOT}%{_libdir64}
done

# copy the binaries we want
for f in certutil cmsutil crlutil modutil pk12util signtool signver ssltap ; do
    install -p -m 755 mozilla-32/dist/*.OBJ/bin/${f} ${RPM_BUILD_ROOT}%{_bindir}
    install -p -m 755 mozilla-64/dist/*.OBJ/bin/${f} ${RPM_BUILD_ROOT}%{_bindir}/${f}_64
done

# copy the binaries we ship as unsupported
mkdir -p ${RPM_BUILD_ROOT}%{unsupported_tools_directory}
mkdir -p ${RPM_BUILD_ROOT}%{unsupported_tools_directory_64}
for f in atob btoa derdump ocspclnt pp selfserv strsclnt symkeyutil tstclnt vfyserv vfychain ; do
    install -p -m 755 mozilla-32/dist/*.OBJ/bin/${f} ${RPM_BUILD_ROOT}%{unsupported_tools_directory}
    install -p -m 755 mozilla-64/dist/*.OBJ/bin/${f} ${RPM_BUILD_ROOT}%{unsupported_tools_directory_64}
done

# copy the include files we want
for f in mozilla-32/dist/public/nss/*.h ; do
    install -p -m 644 ${f} ${RPM_BUILD_ROOT}%{_includedir}/nss3
done

# copy the package configuration files
install -p -m 644 ./mozilla-32/dist/pkgconfig/nss.pc ${RPM_BUILD_ROOT}%{_libdir}/pkgconfig/nss.pc
install -p -m 644 ./mozilla-64/dist/pkgconfig/nss.pc ${RPM_BUILD_ROOT}%{_libdir64}/pkgconfig/nss.pc
install -p -m 755 ./mozilla-32/dist/pkgconfig/nss-config ${RPM_BUILD_ROOT}%{_bindir}/nss-config
install -p -m 755 ./mozilla-64/dist/pkgconfig/nss-config ${RPM_BUILD_ROOT}%{_bindir}/nss-config_64
# copy the pkcs #11 configuration script
install -p -m 755 ./mozilla-32/dist/pkgconfig/setup-nsssysinit.sh ${RPM_BUILD_ROOT}%{_bindir}/setup-nsssysinit.sh
install -p -m 755 ./mozilla-64/dist/pkgconfig/setup-nsssysinit.sh ${RPM_BUILD_ROOT}%{_bindir}/setup-nsssysinit_64.sh

# remove the nss-util-devel headers
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/base64.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/ciferfam.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/nssb64.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/nssb64t.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/nsslocks.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/nssilock.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/nssilckt.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/nssrwlk.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/nssrwlkt.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/nssutil.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/pkcs11.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/pkcs11f.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/pkcs11n.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/pkcs11p.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/pkcs11t.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/pkcs11u.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/portreg.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/secasn1.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/secasn1t.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/seccomon.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/secder.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/secdert.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/secdig.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/secdigt.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/secerr.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/secitem.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/secoid.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/secoidt.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/secport.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/utilrename.h

# remove header shipped in nss-softokn-devel
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/blapit.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/ecl-exp.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/hasht.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/sechash.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/secmodt.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/shsign.h
rm -rf ${RPM_BUILD_ROOT}%{_includedir}/nss3/nsslowhash.h

# strip binaries
/usr/bin/strip -X32_64 ${RPM_BUILD_ROOT}%{_bindir}/* || :

# make symbolic links
(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib lib64
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system)
%dir %{_sysconfdir}/pki/nssdb
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/pki/nssdb/cert8.db
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/pki/nssdb/key3.db
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/pki/nssdb/secmod.db
%{_libdir}/libnss3.so
%{_libdir64}/libnss3.so
%{_libdir}/libssl3.so
%{_libdir64}/libssl3.so
%{_libdir}/libsmime3.so
%{_libdir64}/libsmime3.so
%{_libdir}/libnssckbi.so
%{_libdir64}/libnssckbi.so
%{_libdir}/libnsspem.so
%{_libdir64}/libnsspem.so
/usr/lib/libnss3.so
/usr/lib64/libnss3.so
/usr/lib/libssl3.so
/usr/lib64/libssl3.so
/usr/lib/libsmime3.so
/usr/lib64/libsmime3.so
/usr/lib/libnssckbi.so
/usr/lib64/libnssckbi.so
/usr/lib/libnsspem.so
/usr/lib64/libnsspem.so


%files sysinit
%defattr(-,root,system)
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/pki/nssdb/cert9.db
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/pki/nssdb/key4.db
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/pki/nssdb/pkcs11.txt
%{_bindir}/setup-nsssysinit*.sh
%{_libdir}/libnsssysinit.so
%{_libdir64}/libnsssysinit.so
/usr/bin/setup-nsssysinit*.sh
/usr/lib/libnsssysinit.so
/usr/lib64/libnsssysinit.so


%files tools
%defattr(-,root,system)
%{_bindir}/certutil*
%{_bindir}/cmsutil*
%{_bindir}/crlutil*
%{_bindir}/modutil*
%{_bindir}/pk12util*
%{_bindir}/signtool*
%{_bindir}/signver*
%{_bindir}/ssltap*
%{unsupported_tools_directory}/atob
%{unsupported_tools_directory_64}/atob
%{unsupported_tools_directory}/btoa
%{unsupported_tools_directory_64}/btoa
%{unsupported_tools_directory}/derdump
%{unsupported_tools_directory_64}/derdump
%{unsupported_tools_directory}/ocspclnt
%{unsupported_tools_directory_64}/ocspclnt
%{unsupported_tools_directory}/pp
%{unsupported_tools_directory_64}/pp
%{unsupported_tools_directory}/selfserv
%{unsupported_tools_directory_64}/selfserv
%{unsupported_tools_directory}/strsclnt
%{unsupported_tools_directory_64}/strsclnt
%{unsupported_tools_directory}/symkeyutil
%{unsupported_tools_directory_64}/symkeyutil
%{unsupported_tools_directory}/tstclnt
%{unsupported_tools_directory_64}/tstclnt
%{unsupported_tools_directory}/vfyserv
%{unsupported_tools_directory_64}/vfyserv
%{unsupported_tools_directory}/vfychain
%{unsupported_tools_directory_64}/vfychain
/usr/bin/certutil*
/usr/bin/cmsutil*
/usr/bin/crlutil*
/usr/bin/modutil*
/usr/bin/pk12util*
/usr/bin/signtool*
/usr/bin/signver*
/usr/bin/ssltap*


%files devel
%defattr(-,root,system)
%{_bindir}/nss-config*
%{_libdir}/libcrmf.a
%{_libdir64}/libcrmf.a
%{_libdir}/pkgconfig/nss.pc
%{_libdir64}/pkgconfig/nss.pc

%dir %{_includedir}/nss3
%{_includedir}/nss3/cert.h
%{_includedir}/nss3/certdb.h
%{_includedir}/nss3/certt.h
%{_includedir}/nss3/cmmf.h
%{_includedir}/nss3/cmmft.h
%{_includedir}/nss3/cms.h
%{_includedir}/nss3/cmsreclist.h
%{_includedir}/nss3/cmst.h
%{_includedir}/nss3/crmf.h
%{_includedir}/nss3/crmft.h
%{_includedir}/nss3/cryptohi.h
%{_includedir}/nss3/cryptoht.h
%{_includedir}/nss3/jar-ds.h
%{_includedir}/nss3/jar.h
%{_includedir}/nss3/jarfile.h
%{_includedir}/nss3/key.h
%{_includedir}/nss3/keyhi.h
%{_includedir}/nss3/keyt.h
%{_includedir}/nss3/keythi.h
%{_includedir}/nss3/nss.h
%{_includedir}/nss3/nssckbi.h
%{_includedir}/nss3/nsspem.h
%{_includedir}/nss3/ocsp.h
%{_includedir}/nss3/ocspt.h
%{_includedir}/nss3/p12.h
%{_includedir}/nss3/p12plcy.h
%{_includedir}/nss3/p12t.h
%{_includedir}/nss3/pk11func.h
%{_includedir}/nss3/pk11pqg.h
%{_includedir}/nss3/pk11priv.h
%{_includedir}/nss3/pk11pub.h
%{_includedir}/nss3/pk11sdr.h
%{_includedir}/nss3/pkcs12.h
%{_includedir}/nss3/pkcs12t.h
%{_includedir}/nss3/pkcs7t.h
%{_includedir}/nss3/preenc.h
%{_includedir}/nss3/secmime.h
%{_includedir}/nss3/secmod.h
%{_includedir}/nss3/secpkcs5.h
%{_includedir}/nss3/secpkcs7.h
%{_includedir}/nss3/smime.h
%{_includedir}/nss3/ssl.h
%{_includedir}/nss3/sslerr.h
%{_includedir}/nss3/sslproto.h
%{_includedir}/nss3/sslt.h

/usr/bin/nss-config*
/usr/lib/libcrmf.a
/usr/lib64/libcrmf.a


%files pkcs11-devel
%defattr(-,root,system)
%{_libdir}/libnssb.a
%{_libdir64}/libnssb.a
%{_libdir}/libnssckfw.a
%{_libdir64}/libnssckfw.a
%{_includedir}/nss3/nssbase.h
%{_includedir}/nss3/nssbaset.h
%{_includedir}/nss3/nssckepv.h
%{_includedir}/nss3/nssckft.h
%{_includedir}/nss3/nssckfw.h
%{_includedir}/nss3/nssckfwc.h
%{_includedir}/nss3/nssckfwt.h
%{_includedir}/nss3/nssckg.h
%{_includedir}/nss3/nssckmdt.h
%{_includedir}/nss3/nssckt.h
/usr/lib/libnssb.a
/usr/lib64/libnssb.a
/usr/lib/libnssckfw.a
/usr/lib64/libnssckfw.a


%changelog
* Sat Feb 05 2011 Michael Perzl <michael@perzl.org> - 3.12.9-1
- first version for AIX5L v5.1 and higher
